@@ -83,6 +83,7 @@ static GdkPixbuf *pixbuf_from_url(const gchar *url, const gchar *md5, const gcha
 	curl = curl_easy_init();
 	if (curl == NULL) {
 		g_warning("could not initialize curl to get image from URL");
+		unlink(filename);
 		claws_fclose(file);
 		return NULL;
 	}
@@ -99,8 +100,12 @@ static GdkPixbuf *pixbuf_from_url(const gchar *url, const gchar *md5, const gcha
 	curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
 
 	if (libravatarprefs.allow_redirects) {
-		long maxredirs = (libravatarprefs.default_mode == DEF_MODE_URL)? 3L
-			: ((libravatarprefs.default_mode == DEF_MODE_MM)? 2L: 1L);
+		long maxredirs = (libravatarprefs.default_mode == DEF_MODE_URL)
+			? libravatarprefs.max_redirects_url
+			: ((libravatarprefs.default_mode == DEF_MODE_MM)
+				? libravatarprefs.max_redirects_mm
+				: libravatarprefs.max_redirects_url);
+		debug_print("setting max redirects to %ld\n", maxredirs);
 		curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);
 		curl_easy_setopt(curl, CURLOPT_MAXREDIRS, maxredirs);
 	}
@@ -109,7 +114,8 @@ static GdkPixbuf *pixbuf_from_url(const gchar *url, const gchar *md5, const gcha
 	res = curl_easy_perform(curl);
 	if (res != CURLE_OK) {
 		debug_print("curl_easy_perfom failed: %s", curl_easy_strerror(res));
-		claws_safe_fclose(file);
+		unlink(filename);
+		claws_fclose(file);
 	} else {
 		filesize = ftell(file);
 		claws_safe_fclose(file);
