@@ -436,8 +436,13 @@ static PrefParam param[] = {
 	 &prefs_common.ng_abbrev_len, P_INT,
 	 NULL, NULL, NULL},
 
+#ifdef ENABLE_NLS
+	{"translate_header", "TRUE", &prefs_common.trans_hdr, P_BOOL,
+	 NULL, NULL, NULL},
+#else
 	{"translate_header", "FALSE", &prefs_common.trans_hdr, P_BOOL,
 	 NULL, NULL, NULL},
+#endif
 
 	/* Display: Summary View */
 	{"default_sort_key", "3", &prefs_common.default_sort_key, P_ENUM,
@@ -1054,7 +1059,7 @@ static PrefParam param[] = {
 	{"actionswin_height", "-1", &prefs_common.actionswin_height, P_INT,
 	 NULL, NULL, NULL},
 
-	{"tagswin_width", "486", &prefs_common.tagswin_width, P_INT,
+	{"tagswin_width", "586", &prefs_common.tagswin_width, P_INT,
 	 NULL, NULL, NULL},
 	{"tagswin_height", "-1", &prefs_common.tagswin_height, P_INT,
 	 NULL, NULL, NULL},
